@@ -1,6 +1,6 @@
 from .servers import DataServer
-from .servers import HeapServer
 from .servers import ExecutionServer
+from .servers import ExecutionServerAmqp
 from .servers import InterfaceServer
 from .servers import AdminServer
 from .plugin import AWSpiderPlugin
